mailr3160 - /1.3/test_suite/unit_tests/generic_fns/test_pipes.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on March 13, 2007 - 04:39:
Author: bugman
Date: Tue Mar 13 04:38:54 2007
New Revision: 3160

URL: http://svn.gna.org/viewcvs/relax?rev=3160&view=rev
Log:
Fixed the 'test_deletion_fail()' unit test.

The error throw was RelaxNoRunError and not RelaxError.

Modified:
    1.3/test_suite/unit_tests/generic_fns/test_pipes.py

Modified: 1.3/test_suite/unit_tests/generic_fns/test_pipes.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/generic_fns/test_pipes.py?rev=3160&r1=3159&r2=3160&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/generic_fns/test_pipes.py (original)
+++ 1.3/test_suite/unit_tests/generic_fns/test_pipes.py Tue Mar 13 04:38:54 
2007
@@ -29,7 +29,7 @@
 from data import Data
 from data.pipe_container import PipeContainer
 from generic_fns import pipes
-from relax_errors import RelaxError
+from relax_errors import RelaxError, RelaxNoRunError
 
 
 # The relax data storage object.
@@ -116,8 +116,8 @@
         The function tested is generic_fns.pipes.delete()
         """
 
-        # Assert that a RelaxError occurs when the data pipe does not exist.
-        self.assertRaises(RelaxError, pipes.delete, 'x')
+        # Assert that a RelaxNoRunError occurs when the data pipe does not 
exist.
+        self.assertRaises(RelaxNoRunError, pipes.delete, 'x')
 
 
     def test_unused_cleanup(self):




Related Messages


Powered by MHonArc, Updated Tue Mar 13 05:00:08 2007